NeuralNetwork

Trait NeuralNetwork 

pub trait NeuralNetwork<A>
where Self::Params<A>: RawParams<Elem = A>,
{ type Config: NetworkConfig<String, A>; type Params<_A>; // Required methods fn config(&self) -> &Self::Config; fn params(&self) -> &Self::Params<A>; fn params_mut(&mut self) -> &mut Self::Params<A>; }
The NeuralNetwork trait is used to define the network itself as well as each of its constituent parts.

Required Associated Types

type Config: NetworkConfig<String, A>

The configuration of the neural network defines its architecture and hyperparameters.

type Params<_A>

The parameters of the neural network define its weights and biases.

Required Methods

fn config(&self) -> &Self::Config

returns a reference to the network configuration;

fn params(&self) -> &Self::Params<A>

returns a reference to the network parameters

fn params_mut(&mut self) -> &mut Self::Params<A>

returns a mutable reference to the network parameters

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors